@@ -1,13 +1,14 @@
-# Copyright © 2012-2022 jrnl contributors
+# Copyright © 2012-2023 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
 import argparse
 import logging
 import os
+from typing import Any
 from typing import Callable
 
 import colorama
-import xdg.BaseDirectory
+from rich.pretty import pretty_repr
 from ruamel.yaml import YAML
 from ruamel.yaml import constructor
 
@@ -18,13 +19,10 @@ from jrnl.messages import MsgStyle
 from jrnl.messages import MsgText
 from jrnl.output import list_journals
 from jrnl.output import print_msg
-from jrnl.path import home_dir
+from jrnl.path import get_config_path
+from jrnl.path import get_default_journal_path
 
 # Constants
-DEFAULT_CONFIG_NAME = "jrnl.yaml"
-XDG_RESOURCE = "jrnl"
-
-DEFAULT_JOURNAL_NAME = "journal.txt"
 DEFAULT_JOURNAL_KEY = "default"
 
 YAML_SEPARATOR = ": "
@@ -32,7 +30,6 @@ YAML_FILE_ENCODING = "utf-8"
 
 
 def make_yaml_valid_dict(input: list) -> dict:
-
     """
 
     Convert a two-element list of configuration key-value pair into a flat dict.
@@ -56,7 +53,7 @@ def make_yaml_valid_dict(input: list) -> dict:
     return runtime_modifications
 
 
-def save_config(config, alt_config_path=None):
+def save_config(config: dict, alt_config_path: str | None = None) -> None:
     """Supply alt_config_path if using an alternate config through --config-file."""
     config["version"] = __version__
 
@@ -71,26 +68,7 @@ def save_config(config, alt_config_path=None):
         yaml.dump(config, f)
 
 
-def get_config_path():
-    try:
-        config_directory_path = xdg.BaseDirectory.save_config_path(XDG_RESOURCE)
-    except FileExistsError:
-        raise JrnlException(
-            Message(
-                MsgText.ConfigDirectoryIsFile,
-                MsgStyle.ERROR,
-                {
-                    "config_directory_path": os.path.join(
-                        xdg.BaseDirectory.xdg_config_home, XDG_RESOURCE
-                    )
-                },
-            ),
-        )
-
-    return os.path.join(config_directory_path or home_dir(), DEFAULT_CONFIG_NAME)
-
-
-def get_default_config():
+def get_default_config() -> dict[str, Any]:
     return {
         "version": __version__,
         "journals": {"default": {"journal": get_default_journal_path()}},
@@ -105,20 +83,24 @@ def get_default_config():
         "linewrap": 79,
         "indent_character": "|",
         "colors": {
-            "date": "none",
-            "title": "none",
             "body": "none",
+            "date": "none",
             "tags": "none",
+            "title": "none",
         },
     }
 
 
-def get_default_journal_path():
-    journal_data_path = xdg.BaseDirectory.save_data_path(XDG_RESOURCE) or home_dir()
-    return os.path.join(journal_data_path, DEFAULT_JOURNAL_NAME)
+def get_default_colors() -> dict[str, Any]:
+    return {
+        "body": "none",
+        "date": "black",
+        "tags": "yellow",
+        "title": "cyan",
+    }
 
 
-def scope_config(config, journal_name):
+def scope_config(config: dict, journal_name: str) -> dict:
     if journal_name not in config["journals"]:
         return config
     config = config.copy()
@@ -126,16 +108,19 @@ def scope_config(config, journal_name):
     if type(journal_conf) is dict:
         # We can override the default config on a by-journal basis
         logging.debug(
-            "Updating configuration with specific journal overrides %s", journal_conf
+            "Updating configuration with specific journal overrides:\n%s",
+            pretty_repr(journal_conf),
         )
         config.update(journal_conf)
     else:
         # But also just give them a string to point to the journal file
         config["journal"] = journal_conf
+
+    logging.debug("Scoped config:\n%s", pretty_repr(config))
     return config
 
 
-def verify_config_colors(config):
+def verify_config_colors(config: dict) -> bool:
     """
     Ensures the keys set for colors are valid colorama.Fore attributes, or "None"
     :return: True if all keys are set correctly, False otherwise
@@ -160,7 +145,7 @@ def verify_config_colors(config):
     return all_valid_colors
 
 
-def load_config(config_path):
+def load_config(config_path: str) -> dict:
     """Tries to load a config file from YAML."""
     try:
         with open(config_path, encoding=YAML_FILE_ENCODING) as f:
@@ -183,13 +168,15 @@ def load_config(config_path):
             return yaml.load(f)
 
 
-def is_config_json(config_path):
+def is_config_json(config_path: str) -> bool:
     with open(config_path, "r", encoding="utf-8") as f:
         config_file = f.read()
     return config_file.strip().startswith("{")
 
 
-def update_config(config, new_config, scope, force_local=False):
+def update_config(
+    config: dict, new_config: dict, scope: str | None, force_local: bool = False
+) -> None:
     """Updates a config dict with new values - either global if scope is None
     or config['journals'][scope] is just a string pointing to a journal file,
     or within the scope"""
@@ -202,7 +189,7 @@ def update_config(config, new_config, scope, force_local=False):
         config.update(new_config)
 
 
-def get_journal_name(args, config):
+def get_journal_name(args: argparse.Namespace, config: dict) -> argparse.Namespace:
     args.journal_name = DEFAULT_JOURNAL_KEY
 
     # The first arg might be a journal name
