@@ -1,4 +1,4 @@
-# Copyright © 2012-2022 jrnl contributors
+# Copyright © 2012-2023 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
 from enum import Enum
@@ -28,6 +28,11 @@ class MsgText(Enum):
 
     AllDoneUpgrade = "We're all done here and you can start enjoying jrnl 2"
 
+    InstallComplete = """
+        jrnl configuration created at {config_path}
+        For advanced features, read the docs at https://jrnl.sh
+    """
+
     # --- Prompts --- #
     InstallJournalPathQuestion = """
         Path to your journal file (leave blank for {default_journal_path}):
@@ -37,6 +42,9 @@ class MsgText(Enum):
     EncryptJournalQuestion = """
         Do you want to encrypt your journal? (You can always change this later)
         """
+    UseColorsQuestion = """
+        Do you want jrnl to use colors when displaying entries? (You can always change this later)
+        """
     YesOrNoPromptDefaultYes = "[Y/n]"
     YesOrNoPromptDefaultNo = "[y/N]"
     ContinueUpgrade = "Continue upgrading jrnl?"
@@ -93,12 +101,16 @@ class MsgText(Enum):
         of journal can't be encrypted. Please fix your config file.
         """
 
+    DecryptionFailedGeneric = "The decryption of journal data failed."
+
     KeyboardInterruptMsg = "Aborted by user"
 
     CantReadTemplate = """
-        Unreadable template
-        Could not read template file at:
-        {template}
+        Unable to find a template file {template_path}.
+
+        The following paths were checked:
+         * {jrnl_template_dir}{template_path}
+         * {actual_template_path}
         """
 
     NoNamedJournal = "No '{journal_name}' journal configured\n{journals}"
@@ -149,12 +161,22 @@ class MsgText(Enum):
             https://jrnl.sh/en/stable/external-editors/
         """
 
+    NoEditsReceivedJournalNotDeleted = """
+        No text received from editor. Were you trying to delete all the entries?
+
+        This seems a bit drastic, so the operation was cancelled.
+
+        To delete all entries, use the --delete option.
+        """
+
     NoEditsReceived = "No edits to save, because nothing was changed"
 
     NoTextReceived = """
         No entry to save, because no text was received
         """
-
+    NoChangesToTemplate = """
+        No entry to save, because the template was not changed
+    """
     # --- Upgrade --- #
     JournalFailedUpgrade = """
         The following journal{s} failed to upgrade:
