@@ -1,14 +1,17 @@
-# Copyright © 2012-2022 jrnl contributors
+# Copyright © 2012-2023 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
-from argparse import Namespace
+from typing import TYPE_CHECKING
 
 from jrnl.config import make_yaml_valid_dict
 from jrnl.config import update_config
 
+if TYPE_CHECKING:
+    from argparse import Namespace
+
 
 # import logging
-def apply_overrides(args: Namespace, base_config: dict) -> dict:
+def apply_overrides(args: "Namespace", base_config: dict) -> dict:
     """Unpack CLI provided overrides into the configuration tree.
 
     :param overrides: List of configuration key-value pairs collected from the CLI
@@ -18,13 +21,12 @@ def apply_overrides(args: Namespace, base_config: dict) -> dict:
     :return: Configuration to be used during runtime with the overrides applied
     :rtype: dict
     """
-    overrides = vars(args).get("config_override", None)
+    overrides = vars(args).get("config_override")
     if not overrides:
         return base_config
 
     cfg_with_overrides = base_config.copy()
     for pairs in overrides:
-
         pairs = make_yaml_valid_dict(pairs)
         key_as_dots, override_value = _get_key_and_value_from_pair(pairs)
         keys = _convert_dots_to_list(key_as_dots)
@@ -36,12 +38,12 @@ def apply_overrides(args: Namespace, base_config: dict) -> dict:
     return base_config
 
 
-def _get_key_and_value_from_pair(pairs):
+def _get_key_and_value_from_pair(pairs: dict) -> tuple:
     key_as_dots, override_value = list(pairs.items())[0]
     return key_as_dots, override_value
 
 
-def _convert_dots_to_list(key_as_dots):
+def _convert_dots_to_list(key_as_dots: str) -> list[str]:
     keys = key_as_dots.split(".")
     keys = [k for k in keys if k != ""]  # remove empty elements
     return keys
