@@ -1,8 +1,9 @@
-# Copyright (C) 2012-2022 jrnl contributors
+# Copyright © 2012-2023 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
 import os
 import re
+from typing import TYPE_CHECKING
 
 from jrnl.messages import Message
 from jrnl.messages import MsgStyle
@@ -10,6 +11,10 @@ from jrnl.messages import MsgText
 from jrnl.output import print_msg
 from jrnl.plugins.text_exporter import TextExporter
 
+if TYPE_CHECKING:
+    from jrnl.journals import Entry
+    from jrnl.journals import Journal
+
 
 class MarkdownExporter(TextExporter):
     """This Exporter can convert entries and journals into Markdown."""
@@ -18,7 +23,7 @@ class MarkdownExporter(TextExporter):
     extension = "md"
 
     @classmethod
-    def export_entry(cls, entry, to_multifile=True):
+    def export_entry(cls, entry: "Entry", to_multifile: bool = True) -> str:
         """Returns a markdown representation of a single entry."""
         date_str = entry.date.strftime(entry.journal.config["timeformat"])
         body_wrapper = "\n" if entry.body else ""
@@ -73,16 +78,16 @@ class MarkdownExporter(TextExporter):
         return f"{heading} {date_str} {entry.title}\n{newbody} "
 
     @classmethod
-    def export_journal(cls, journal):
+    def export_journal(cls, journal: "Journal") -> str:
         """Returns a Markdown representation of an entire journal."""
         out = []
         year, month = -1, -1
         for e in journal.entries:
-            if not e.date.year == year:
+            if e.date.year != year:
                 year = e.date.year
                 out.append("# " + str(year))
                 out.append("")
-            if not e.date.month == month:
+            if e.date.month != month:
                 month = e.date.month
                 out.append("## " + e.date.strftime("%B"))
                 out.append("")
