@@ -1,9 +1,15 @@
-# Copyright © 2012-2022 jrnl contributors
+# Copyright © 2012-2023 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
+from typing import TYPE_CHECKING
+
 from jrnl.plugins.text_exporter import TextExporter
 from jrnl.plugins.util import get_tags_count
 
+if TYPE_CHECKING:
+    from jrnl.journals import Entry
+    from jrnl.journals import Journal
+
 
 class TagExporter(TextExporter):
     """This Exporter can lists the tags for entries and journals, exported as a plain text file."""
@@ -12,12 +18,12 @@ class TagExporter(TextExporter):
     extension = "tags"
 
     @classmethod
-    def export_entry(cls, entry):
+    def export_entry(cls, entry: "Entry") -> str:
         """Returns a list of tags for a single entry."""
         return ", ".join(entry.tags)
 
     @classmethod
-    def export_journal(cls, journal):
+    def export_journal(cls, journal: "Journal") -> str:
         """Returns a list of tags and their frequency for an entire journal."""
         tag_counts = get_tags_count(journal)
         result = ""
