@@ -1,4 +1,4 @@
-# Copyright © 2012-2022 jrnl contributors
+# Copyright © 2012-2023 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
 import datetime
@@ -22,15 +22,19 @@ def __get_pdt_calendar():
 
 
 def parse(
-    date_str, inclusive=False, default_hour=None, default_minute=None, bracketed=False
-):
+    date_str: str | datetime.datetime,
+    inclusive: bool = False,
+    default_hour: int | None = None,
+    default_minute: int | None = None,
+    bracketed: bool = False,
+) -> datetime.datetime | None:
     """Parses a string containing a fuzzy date and returns a datetime.datetime object"""
     if not date_str:
         return None
     elif isinstance(date_str, datetime.datetime):
         return date_str
 
-    # Don't try to parse anything with 6 or less characters and was parsed from the existing journal.
+    # Don't try to parse anything with 6 or fewer characters and was parsed from the existing journal.
     # It's probably a markdown footnote
     if len(date_str) <= 6 and bracketed:
         return None
@@ -79,9 +83,17 @@ def parse(
         date = datetime.datetime(*date[:6])
 
     # Ugly heuristic: if the date is more than 4 weeks in the future, we got the year wrong.
-    # Rather then this, we would like to see parsedatetime patched so we can tell it to prefer
+    # Rather than this, we would like to see parsedatetime patched so we can tell it to prefer
     # past dates
     dt = datetime.datetime.now() - date
     if dt.days < -28 and not year_present:
         date = date.replace(date.year - 1)
     return date
+
+
+def is_valid_date(year: int, month: int, day: int) -> bool:
+    try:
+        datetime.datetime(year, month, day)
+        return True
+    except ValueError:
+        return False
